@@ -79,58 +79,70 @@ hy_sed_daily_suscon <- function(station_number = NULL,
 
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
+  
+  ## Creating rlang symbols
+  sym_YEAR <- sym("YEAR")
+  sym_STATION_NUMBER <- sym("STATION_NUMBER")
+  sym_variable <- sym("variable")
+  sym_temp <- sym("temp")
+  sym_Date <- sym("Date")
 
   ## Data manipulations
   sed_dly_suscon <- dplyr::tbl(hydat_con, "SED_DLY_SUSCON")
-  sed_dly_suscon <- dplyr::filter(sed_dly_suscon, STATION_NUMBER %in% stns)
+  sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_STATION_NUMBER %in% stns)
 
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
   if (start_date != "ALL" | end_date != "ALL") {
-    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, YEAR >= start_year &
-      YEAR <= end_year)
+    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_YEAR >= start_year &
+                                      !!sym_YEAR <= end_year)
   }
 
-  sed_dly_suscon <- dplyr::select(sed_dly_suscon, STATION_NUMBER, YEAR, MONTH, NO_DAYS, dplyr::contains("SUSCON"))
+  sed_dly_suscon <- dplyr::select(sed_dly_suscon, .data$STATION_NUMBER, .data$YEAR, .data$MONTH, .data$NO_DAYS,
+                                  dplyr::contains("SUSCON"))
   sed_dly_suscon <- dplyr::collect(sed_dly_suscon)
   
   if(is.data.frame(sed_dly_suscon) && nrow(sed_dly_suscon)==0)
   {stop("No suspended sediment data for this station in HYDAT")}
   
-  sed_dly_suscon <- tidyr::gather(sed_dly_suscon, variable, temp, -(STATION_NUMBER:NO_DAYS))
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, DAY = as.numeric(gsub("SUSCON|SUSCON_SYMBOL", "", variable)))
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, variable = gsub("[0-9]+", "", variable))
-  sed_dly_suscon <- tidyr::spread(sed_dly_suscon, variable, temp)
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, SUSCON = as.numeric(SUSCON))
+  sed_dly_suscon <- tidyr::gather(sed_dly_suscon, !!sym_variable, !!sym_temp, -(.data$STATION_NUMBER:.data$NO_DAYS))
+  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, DAY = as.numeric(gsub("SUSCON|SUSCON_SYMBOL", "", .data$variable)))
+  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, variable = gsub("[0-9]+", "", .data$variable))
+  sed_dly_suscon <- tidyr::spread(sed_dly_suscon, !!sym_variable, !!sym_temp)
+  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, SUSCON = as.numeric(.data$SUSCON))
   ## No days that exceed actual number of days in the month
-  sed_dly_suscon <- dplyr::filter(sed_dly_suscon, DAY <= NO_DAYS)
+  sed_dly_suscon <- dplyr::filter(sed_dly_suscon, .data$DAY <= .data$NO_DAYS)
 
   ## convert into R date.
-  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, Date = lubridate::ymd(paste0(YEAR, "-", MONTH, "-", DAY)))
+  sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, Date = lubridate::ymd(
+    paste0(.data$YEAR, "-", .data$MONTH, "-", .data$DAY)))
 
   ## Then when a date column exist fine tune the subset
   if (start_date != "ALL" | end_date != "ALL") {
-    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, Date >= start_date &
-      Date <= end_date)
+    sed_dly_suscon <- dplyr::filter(sed_dly_suscon, !!sym_Date >= start_date &
+                                      !!sym_Date <= end_date)
   }
   
   
-  sed_dly_suscon <- dplyr::left_join(sed_dly_suscon, hy_data_symbols, by = c("SUSCON_SYMBOL" = "SYMBOL_ID"))
+  sed_dly_suscon <- dplyr::left_join(sed_dly_suscon, tidyhydat::hy_data_symbols, by = c("SUSCON_SYMBOL" = "SYMBOL_ID"))
   sed_dly_suscon <- dplyr::mutate(sed_dly_suscon, Parameter = "Suscon")
   
   ## Control for symbol ouput
   if(symbol_output == "code"){
-    sed_dly_suscon <- dplyr::select(sed_dly_suscon, STATION_NUMBER, Date, Parameter, SUSCON, SUSCON_SYMBOL)
+    sed_dly_suscon <- dplyr::select(sed_dly_suscon, .data$STATION_NUMBER, .data$Date, .data$Parameter, 
+                                    .data$SUSCON, .data$SUSCON_SYMBOL)
   }
   
   if(symbol_output == "english"){
-    sed_dly_suscon <- dplyr::select(sed_dly_suscon, STATION_NUMBER, Date, Parameter, SUSCON, SYMBOL_EN)
+    sed_dly_suscon <- dplyr::select(sed_dly_suscon, .data$STATION_NUMBER, .data$Date, .data$Parameter, 
+                                    .data$SUSCON, .data$SYMBOL_EN)
   }
   
   if(symbol_output == "french"){
-    sed_dly_suscon <- dplyr::select(sed_dly_suscon, STATION_NUMBER, Date, Parameter, SUSCON, SYMBOL_FR)
+    sed_dly_suscon <- dplyr::select(sed_dly_suscon, .data$STATION_NUMBER, .data$Date, .data$Parameter, 
+                                    .data$SUSCON, .data$SYMBOL_FR)
   }
   
-  sed_dly_suscon <- dplyr::arrange(sed_dly_suscon, Date)
+  sed_dly_suscon <- dplyr::arrange(sed_dly_suscon, .data$Date)
 
   colnames(sed_dly_suscon) <- c("STATION_NUMBER", "Date", "Parameter", "Value", "Symbol")
 
