@@ -81,10 +81,14 @@ hy_sed_samples_psd <- function(station_number = NULL,
 
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
+  
+  ## Creating rlang symbols
+  sym_STATION_NUMBER <- sym("STATION_NUMBER")
+  sym_DATE <- sym("DATE")
 
   ## Data manipulations
   sed_samples_psd <- dplyr::tbl(hydat_con, "SED_SAMPLES_PSD")
-  sed_samples_psd <- dplyr::filter(sed_samples_psd, STATION_NUMBER %in% stns)
+  sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym_STATION_NUMBER %in% stns)
   sed_samples_psd <- dplyr::left_join(sed_samples_psd, dplyr::tbl(hydat_con, "SED_DATA_TYPES"), by = c("SED_DATA_TYPE"))
 
   sed_samples_psd <- dplyr::collect(sed_samples_psd)
@@ -92,16 +96,17 @@ hy_sed_samples_psd <- function(station_number = NULL,
   if(is.data.frame(sed_samples_psd) && nrow(sed_samples_psd)==0)
   {stop("This station is not present in HYDAT")}
   
-  sed_samples_psd <- dplyr::mutate(sed_samples_psd, DATE = lubridate::ymd_hms(DATE))
+  sed_samples_psd <- dplyr::mutate(sed_samples_psd, DATE = lubridate::ymd_hms(.data$DATE))
 
   ## SUBSET by date
   if (start_date != "ALL" | end_date != "ALL") {
-    sed_samples_psd <- dplyr::filter(sed_samples_psd, DATE >= start_date &
-      DATE <= end_date)
+    sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym_DATE >= start_date &
+      !!sym_DATE <= end_date)
   }
   
   
-  sed_samples_psd <- dplyr::select(sed_samples_psd, STATION_NUMBER, SED_DATA_TYPE_EN, DATE, PARTICLE_SIZE, PERCENT)
+  sed_samples_psd <- dplyr::select(sed_samples_psd, .data$STATION_NUMBER, .data$SED_DATA_TYPE_EN, .data$DATE,
+                                   .data$PARTICLE_SIZE, .data$PERCENT)
   
   
   ## What stations were missed?
