@@ -46,23 +46,11 @@ test_that("hy_monthly_levels produces an error when a province is not specified
             ))
           })
 
-test_that("hy_monthly_levels can accept both arguments for backward compatability",
-          {
-            expect_true(nrow(
-              hy_monthly_levels(
-                prov_terr_state_loc = "BC",
-                station_number = "08MF005",
-                hydat_path = hy_test_db()
-              )
-            ) >= 1)
-          })
-
 
 test_that("hy_monthly_levels respects Year specification", {
   date_vector <- c("2013-01-01", "2014-01-01")
   temp_df <- hy_monthly_levels(
     station_number = "08MF005",
-    prov_terr_state_loc = "BC",
     hydat_path = hy_test_db(),
     start_date = date_vector[1],
     end_date = date_vector[2]
