@@ -3,7 +3,7 @@ context("Testing minor lookup tables for STN_* functions")
 test_that("hy_stn_remarks returns a dataframe", {
   expect_is(hy_stn_remarks(
     station_number = "08MF005",
-    hydat_path = system.file("test_db/tinyhydat.sqlite3", package = "tidyhydat")
+    hydat_path = hy_test_db()
   ),
   class = "tbl_df")
 })
@@ -11,7 +11,7 @@ test_that("hy_stn_remarks returns a dataframe", {
 test_that("hy_stn_datum_conv returns a dataframe", {
   expect_is(hy_stn_datum_conv(
     station_number = "08MF005",
-    hydat_path = system.file("test_db/tinyhydat.sqlite3", package = "tidyhydat")
+    hydat_path = hy_test_db()
   ),
   class = "tbl_df")
 })
@@ -21,7 +21,7 @@ test_that("hy_stn_datum_conv returns a dataframe", {
 test_that("hy_stn_data_range returns a dataframe", {
   expect_is(hy_stn_data_range(
     station_number = "08MF005",
-    hydat_path = system.file("test_db/tinyhydat.sqlite3", package = "tidyhydat")
+    hydat_path = hy_test_db()
   ),
   class = "tbl_df")
 })
@@ -29,7 +29,7 @@ test_that("hy_stn_data_range returns a dataframe", {
 test_that("hy_stn_data_coll returns a dataframe", {
   expect_is(hy_stn_data_coll(
     station_number = "08MF005",
-    hydat_path = system.file("test_db/tinyhydat.sqlite3", package = "tidyhydat")
+    hydat_path = hy_test_db()
   ),
   class = "tbl_df")
 })
@@ -37,7 +37,7 @@ test_that("hy_stn_data_coll returns a dataframe", {
 test_that("hy_stn_op_schedule returns a dataframe", {
   expect_is(hy_stn_op_schedule(
     station_number = "08MF005",
-    hydat_path = system.file("test_db/tinyhydat.sqlite3", package = "tidyhydat")
+    hydat_path = hy_test_db()
   ),
   class = "tbl_df")
 })
